<?php

declare(strict_types=1);

namespace apexl\Io\interfaces;

use apexl\Vault\interfaces\QueryBuilderInterface;

interface LoaderConditionInterface
{
    public function applyToQuery(QueryBuilderInterface $query): QueryBuilderInterface;

    public function shouldWrap(): bool;
}
